You can also browse all files on .tar.gz/">fossies.org or in the git repo.

htdocs/
  HTML files of the web pages you are looking at.
  css/
    Directory containing example CSS files (cascaded style sheets).
    web2ldap/
      CSS files of the application.
etc/
  web2ldap/
    templates/
      various HTML and LDIF templates for displaying entries and input forms and for setting defaults of new entries to be added
    web2ldapcnf/
      the configuration module package
      - __init__.py
      - hosts.py
      - plugins.py -- defines which plugin modules to import
  systemd/
    web2ldap-standalone.service
      Starting web2ldap as stand-alone HTTP server with systemd.
  apache2/
    Example configuration files for WSGI integration with Apache httpd.
  uwsgi/
    Example configuration files for integration with UWSGI.
web2ldap/
  the application's module package
  app/plugins/
    The pre-installed plugin modules